@@ -1,4 +1,4 @@
-{-# LANGUAGE RankNTypes, ScopedTypeVariables,
+{-# LANGUAGE CPP, RankNTypes, ScopedTypeVariables,
              GeneralizedNewtypeDeriving, DeriveDataTypeable #-}
 
 -- TODO: Can we pattern match on functions?
@@ -12,7 +12,7 @@
 
 -- |
 -- Module      :  Test.ChasingBottoms.ContinuousFunctions
--- Copyright   :  (c) Nils Anders Danielsson 2005-2013
+-- Copyright   :  (c) Nils Anders Danielsson 2005-2014
 -- License     :  See the file LICENCE.
 --
 -- Maintainer  :  http://www.cse.chalmers.se/~nad/
@@ -143,13 +143,23 @@ module Test.ChasingBottoms.ContinuousFunctions
   , listOf
   ) where
 
-import Test.QuickCheck hiding ((><), listOf)
+import Test.QuickCheck
+  hiding ( (><)
+         , listOf
+#if MIN_VERSION_QuickCheck(2,7,0)
+         , infiniteListOf
+#endif
+         )
+#if MIN_VERSION_QuickCheck(2,7,0)
+import Test.QuickCheck.Gen.Unsafe (promote)
+#endif
 import Data.Sequence as Seq
 import Data.Foldable as Seq (foldr)
 import Prelude as P hiding (concat)
 import Test.ChasingBottoms.IsBottom
 import Control.Monad
 import Control.Monad.Reader
+import Control.Applicative
 import Control.Arrow
 import System.Random
 import Data.Generics
@@ -264,7 +274,7 @@ match x = PatternMatch
 
 newtype MakeResult a
   = MR { unMR :: ReaderT PatternMatches Gen a }
-    deriving (Functor, Monad)
+    deriving (Functor, Applicative, Monad)
 
 type PatternMatches = Seq PatternMatch
 
